AdvancedPlayerManager class

Advanced Player Manager with auto-play, recommendations, and smart features

Properties

events Stream<ManagerEvent>
no setter
hashCode int
The hash code for this object.
no setterinherited
player LavalinkPlayerController
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTrack(Track track, {bool checkDuplicates = true}) Future<bool>
Add track with smart features
addTracks(List<Track> tracks, {bool checkDuplicates = true}) Future<int>
Add multiple tracks with deduplication
clearHistory() → void
Clear history
disableAutoPlay() → void
Disable auto-play
enableAutoPlay() → void
Enable auto-play (automatically plays similar songs when queue is empty)
enableSmartQueue() → void
Enable smart queue (prevents duplicate tracks)
getStatistics() PlayerStatistics
Get statistics
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited