PlayerStatistics class

Constructors

PlayerStatistics({required int totalTracksPlayed, required int currentQueueSize, required int historySize, required bool isPlaying, required bool isPaused, required int currentVolume, required String repeatMode})

Properties

currentQueueSize int
final
currentVolume int
final
hashCode int
The hash code for this object.
no setterinherited
historySize int
final
isPaused bool
final
isPlaying bool
final
repeatMode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTracksPlayed int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited