AdvancedSearch class

Advanced Search with caching and multi-source aggregation

Constructors

AdvancedSearch(dynamic lavalinkClient, {Duration cacheExpiry = const Duration(hours: 1)})

Properties

cacheExpiry Duration
final
hashCode int
The hash code for this object.
no setterinherited
lavalinkClient → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCache() → void
Clear cache
getRecommendations(Track track) Future<List<Track>>
Get recommendations based on track
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Search with caching
searchAll(String query) Future<Map<String, List<Track>>>
Search across all sources and merge results
searchFiltered(String query, {Duration? minDuration, Duration? maxDuration, String? requiredWord}) Future<List<Track>>
Search with filters
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited