BassBoostCommand class

Inheritance

Constructors

BassBoostCommand()

Properties

aliases List<String>
finalinherited
description String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
requiresDJ bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage String
finalinherited

Methods

execute(CommandContext context) Future<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited