CommandHandler class abstract

Base command handler

Implementers

Constructors

CommandHandler({bool requiresDJ = false, required String description, required String usage, List<String> aliases = const []})
const

Properties

aliases List<String>
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
requiresDJ bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage String
final

Methods

execute(CommandContext context) Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited