SeekingCommands class
Seeking control commands
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forward(
CommandContext ctx) → Future< String> -
restart(
CommandContext ctx) → Future< String> -
rewind(
CommandContext ctx) → Future< String> -
seek(
CommandContext ctx) → Future< String>