MusicBotFramework class

Advanced Music Bot Framework - Makes bot creation SUPER EASY

Features:

  • Automatic command handling
  • Built-in music commands
  • Easy customization
  • Event system
  • Permission management
  • Playlist management
  • Auto-queue system
  • DJ mode

Constructors

MusicBotFramework({required LavalinkClient lavalinkClient, String prefix = '!', bool autoQueue = true, bool djMode = false, List<String> djRoles = const []})

Properties

autoQueue bool
final
djMode bool
final
djRoles List<String>
final
events Stream<BotEvent>
no setter
hashCode int
The hash code for this object.
no setterinherited
lavalinkClient LavalinkClient
final
prefix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlayer(String guildId) LavalinkPlayerController
handleMessage({required String message, required String userId, required String guildId, required String channelId, List<String> userRoles = const []}) Future<String?>
Handle incoming message
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerCommand(String name, CommandHandler handler) → void
Register a custom command
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited