TrackEndEvent class

Event sent when a track ends

Inheritance

Constructors

TrackEndEvent({required String guildId, required Track track, required String reason})
TrackEndEvent.fromJson(Map<String, dynamic> json)
factory

Properties

cleanup bool
no setter
finished bool
no setter
guildId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
loadFailed bool
no setter
reason String
final
replaced bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopped bool
no setter
track Track
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited