TrackStuckEvent class
Event sent when a track gets stuck
- Inheritance
-
- Object
- LavalinkEvent
- TrackStuckEvent
Constructors
- TrackStuckEvent({required String guildId, required Track track, required int thresholdMs})
-
TrackStuckEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- guildId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thresholdMs → int
-
final
- track → Track
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited