WebSocketClosedEvent class

Event sent when the WebSocket connection is closed

Inheritance

Constructors

WebSocketClosedEvent({required String guildId, required int code, required String reason, required bool byRemote})
WebSocketClosedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

byRemote bool
final
code int
final
guildId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
reason String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited