Equalizer class

Audio filters for Lavalink

Provides various audio effects and filters that can be applied to playback Equalizer filter - adjust frequencies

Constructors

Equalizer({required List<EqualizerBand> bands})
Equalizer.bassBoost()
Preset: Bass boost
factory
Equalizer.soft()
Preset: Soft (reduce harsh frequencies)
factory
Equalizer.trebleBoost()
Preset: Treble boost
factory

Properties

bands List<EqualizerBand>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited