FilterConfig class
Combined filter configuration
Constructors
- FilterConfig({double? volume, Equalizer? equalizer, Karaoke? karaoke, Timescale? timescale, Tremolo? tremolo, Vibrato? vibrato, Rotation? rotation, Distortion? distortion, ChannelMix? channelMix, LowPass? lowPass})
Properties
- channelMix → ChannelMix?
-
final
- distortion → Distortion?
-
final
- equalizer → Equalizer?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- karaoke → Karaoke?
-
final
- lowPass → LowPass?
-
final
- rotation → Rotation?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timescale → Timescale?
-
final
- tremolo → Tremolo?
-
final
- vibrato → Vibrato?
-
final
- volume → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clear(
) → FilterConfig - Clear all filters