Karaoke class

Karaoke filter - remove vocals

Constructors

Karaoke({double? level, double? monoLevel, double? filterBand, double? filterWidth})
Karaoke.preset()
factory

Properties

filterBand double?
final
filterWidth double?
final
hashCode int
The hash code for this object.
no setterinherited
level double?
final
monoLevel double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited