Cpu class

Constructors

Cpu({required int cores, required double systemLoad, required double lavalinkLoad})
Cpu.fromJson(Map<String, dynamic> json)
factory

Properties

cores int
final
hashCode int
The hash code for this object.
no setterinherited
lavalinkLoad double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemLoad double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited