Git class

Constructors

Git({required String branch, required String commit, required int commitTime})
Git.fromJson(Map<String, dynamic> json)
factory

Properties

branch String
final
commit String
final
commitTime int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited