Stats class

Lavalink server statistics

Constructors

Stats({required int players, required int playingPlayers, required int uptime, required Memory memory, required Cpu cpu, FrameStats? frameStats})
Stats.fromJson(Map<String, dynamic> json)
factory

Properties

cpu Cpu
final
frameStats FrameStats?
final
hashCode int
The hash code for this object.
no setterinherited
memory Memory
final
players int
final
playingPlayers int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uptime int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited