Player class
Player state
Constructors
-
Player({required String guildId, Track? track, required int volume, required bool paused, required PlayerState state, VoiceState? voice, Map<
String, dynamic> ? filters}) -
Player.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
filters
→ Map<
String, dynamic> ? -
final
- guildId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- paused → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → PlayerState
-
final
- track → Track?
-
final
- voice → VoiceState?
-
final
- volume → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited