PlayerState class

Player state information

Constructors

PlayerState({required int time, required int position, required bool connected, required int ping})
PlayerState.fromJson(Map<String, dynamic> json)
factory

Properties

connected bool
final
hashCode int
The hash code for this object.
no setterinherited
ping int
final
position int
final
positionDuration Duration
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited