PlayerUpdate class

Player update request

Constructors

PlayerUpdate({String? encodedTrack, int? position, int? endTime, int? volume, bool? paused, Map<String, dynamic>? filters, VoiceState? voice})
PlayerUpdate.stop()

Properties

encodedTrack String?
final
endTime int?
final
filters Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
paused bool?
final
position int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voice VoiceState?
final
volume int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited