Track class

Represents a Lavalink track

Constructors

Track({required String encoded, required TrackInfo info, Map<String, dynamic>? pluginInfo})
Track.fromJson(Map<String, dynamic> json)
factory

Properties

encoded → String
final
hashCode → int
The hash code for this object.
no setterinherited
info → TrackInfo
final
pluginInfo → Map<String, dynamic>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited