LavalinkWebSocket class

Lavalink WebSocket client

Constructors

LavalinkWebSocket({required String host, required int port, required String password, required String userId, bool useSSL = false, Duration heartbeatInterval = const Duration(seconds: 30), int maxReconnectAttempts = 10})

Properties

eventStream Stream
no setter
hashCode int
The hash code for this object.
no setterinherited
heartbeatInterval Duration
final
host String
final
isConnected bool
no setter
maxReconnectAttempts int
final
password String
final
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
no setter
userId String
final
useSSL bool
final

Methods

connect() Future<void>
Connect to Lavalink WebSocket
disconnect() Future<void>
Disconnect from WebSocket
dispose() Future<void>
Dispose the WebSocket client
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited