CommandContext class

Command context for bot commands

Constructors

CommandContext({required dynamic framework, required String userId, required String guildId, required String channelId, required List<String> args, required List<String> userRoles})

Properties

args List<String>
final
channelId String
final
client → dynamic
Get Lavalink client
no setter
framework → dynamic
final
guildId String
final
hasArgs bool
Check if has arguments
no setter
hashCode int
The hash code for this object.
no setterinherited
joinedArgs String
Join arguments into single string
no setter
player → dynamic
Get player for this guild
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
final
userRoles List<String>
final

Methods

hasRole(String roleId) bool
Check if user has specific role
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited