CommandHandler class abstract
Base command handler
- Implementers
- Apply8DCommand
- BassBoostCommand
- ClearFiltersCommand
- ClearQueueCommand
- ForwardCommand
- HelpCommand
- KaraokeCommand
- ListPlaylistsCommand
- LoadPlaylistCommand
- LyricsCommand
- MoveCommand
- MuteCommand
- NightcoreCommand
- NowPlayingCommand
- PauseCommand
- PingCommand
- PlayCommand
- PreviousCommand
- QueueCommand
- RemoveCommand
- RepeatCommand
- RestartCommand
- ResumeCommand
- RewindCommand
- SavePlaylistCommand
- SeekCommand
- ShuffleCommand
- SkipCommand
- StopCommand
- UnmuteCommand
- VaporwaveCommand
- VolumeCommand
Constructors
Properties
-
aliases
→ List<
String> -
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requiresDJ → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usage → String
-
final
Methods
-
execute(
CommandContext context) → Future< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited