TrackExceptionEvent class
Event sent when a track throws an exception
- Inheritance
-
- Object
- LavalinkEvent
- TrackExceptionEvent
Constructors
- TrackExceptionEvent({required String guildId, required Track track, required TrackException exception})
-
TrackExceptionEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- exception → TrackException
-
final
- guildId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- track → Track
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited