ChannelMix class
Channel mix filter
Constructors
- ChannelMix({required double leftToLeft, required double leftToRight, required double rightToLeft, required double rightToRight})
- ChannelMix.mono()
-
Mono preset
factory
- ChannelMix.reverseStereo()
-
Reverse stereo
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- leftToLeft → double
-
final
- leftToRight → double
-
final
- rightToLeft → double
-
final
- rightToRight → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited