Distortion class

Distortion filter

Constructors

Distortion({required double sinOffset, required double sinScale, required double cosOffset, required double cosScale, required double tanOffset, required double tanScale, required double offset, required double scale})

Properties

cosOffset double
final
cosScale double
final
hashCode int
The hash code for this object.
no setterinherited
offset double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
final
sinOffset double
final
sinScale double
final
tanOffset double
final
tanScale double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited