Rotation class

Rotation filter - 8D audio effect

Constructors

Rotation({required double rotationHz})
Rotation.fast()
Preset: Fast rotation
factory
Rotation.slow()
Preset: Slow rotation
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
rotationHz double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited