Timescale class

Timescale filter - change speed/pitch/rate

Constructors

Timescale({double? speed, double? pitch, double? rate})
Timescale.chipmunk()
Chipmunk preset (higher pitch)
factory
Timescale.nightcore()
Nightcore preset (faster, higher pitch)
factory
Timescale.vaporwave()
Vaporwave preset (slower, lower pitch)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
pitch double?
final
rate double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited