Info class
Lavalink server information
Constructors
Properties
- buildTime → int
-
final
- git → Git
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- jvm → String
-
final
- lavaplayer → String
-
final
-
plugins
→ List<
Plugin> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceManagers
→ List<
String> -
final
- version → Version
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited