LoadResult class

Result from loading tracks

Constructors

LoadResult({required LoadType loadType, required dynamic data})
LoadResult.fromJson(Map<String, dynamic> json)
factory

Properties

data → dynamic
final
exception LoadException?
no setter
hashCode int
The hash code for this object.
no setterinherited
loadType LoadType
final
playlist PlaylistInfo?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchResults List<Track>?
no setter
track Track?
no setter
tracks List<Track>?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited