MultiSourceSearchResult class
Search result with multiple sources
Constructors
-
MultiSourceSearchResult({required Map<
String, LoadResult> results, required Duration searchTime})
Properties
-
allTracks
→ List<
Track> -
Get all tracks from all sources
no setter
- bestResult → LoadResult?
-
Get best result (most tracks)
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
results
→ Map<
String, LoadResult> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchTime → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited