TrackInfo class
Track information
Constructors
- TrackInfo({required String identifier, required bool isSeekable, required String author, required int length, required bool isStream, required int position, required String title, String? uri, String? artworkUrl, String? isrc, required String sourceName})
-
TrackInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- artworkUrl → String?
-
final
-
final
- duration → Duration
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- isrc → String?
-
final
- isSeekable → bool
-
final
- isStream → bool
-
final
- length → int
-
final
- position → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceName → String
-
final
- title → String
-
final
- uri → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited